/*
** Module   : ChuiLinuxKeyboard.java
** Abstract : Keyboard configuration for Linux ChUI clients. 
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20141029 Created initial version.
*/

package com.goldencode.p2j.ui.client.chui;

import java.util.*;

import com.goldencode.p2j.ui.*;

/**
 * This class contains the configurations for a Keyboard compatible with the Linux ChUI clients.
 */
public class ChuiLinuxKeyboard
extends Keyboard
{
   /**
    * Default c'tor.  Sets the {@link Keyboard#bit10} label to <code>ESC</code>.
    */
   public ChuiLinuxKeyboard()
   {
      super("ESC");
   }
   
   /**
    * Initialize this keyboard.
    */
   @Override
   public void init()
   {
      super.init();
      
      basicKeys[13] = "RETURN";
      basicKeys[509] = "BACK-TAB";
      basicKeys[512] = "DEL-CHAR";
      basicKeys[525] = "RETURN";
      basicKeys[610] = "MOUSE-MOVE-UP";
      basicKeys[618] = "MOUSE-MOVE-DOWN";
      basicKeys[626] = "MOUSE-MOVE-CLICK";
      basicKeys[650] = "MOUSE-MOVE-DBLCLICK";

      // filling the map of alternate key labels
      addAltLabel("ENTER", 13);
      addAltLabel("SHIFT-TAB", 509);

      addAltLabel(MIDDLE_MOUSE_DOWN,      keyCode(MOUSE_MOVE_DOWN));
      addAltLabel(MIDDLE_MOUSE_UP,        keyCode(MOUSE_MOVE_UP));
      addAltLabel(MIDDLE_MOUSE_CLICK,     keyCode(MOUSE_MOVE_CLICK));
      addAltLabel(MIDDLE_MOUSE_DBLCLICK,  keyCode(MOUSE_MOVE_DBLCLICK));
   }
   
   /**
    * Get the mappings of standard functions to their associated keys.
    * 
    * @return   See above.
    */
   @Override
   protected Map<String, String[]> standardKeyFunctions()
   {
      Map<String, String[]> res = new HashMap<>();
      
      res.put(ABORT,       new String[] {"CTRL-\\"});
      res.put(APPEND_LINE, new String[] {"CTRL-A"});
      
      res.put(BACK_TAB,      new String[] {"BACK-TAB", "CTRL-U"});
      res.put(BACKSPACE,     new String[] {"BACKSPACE", "CTRL-H", "DEL-CHAR"});
      res.put(BELL,          new String[] {"BELL"});
      res.put(BLOCK,         new String[] {"CTRL-V"});
      res.put(BOTTOM_COLUMN, new String[] {"ESC-CTRL-B"});
      res.put(BREAK_LINE,    new String[] {"ESC-B"});

      res.put(CANCEL_PICK,  new String[] {"ESC-CTRL-X"});
      res.put(CHOICES,      new String[] {"ESC-BACKSPACE", "ESC-CTRL-H"});
      res.put(CLEAR,        new String[] {"F8", "CTRL-Z"});
      res.put(CLOSE,        new String[] {"ESC-Z"});
      res.put(COMPILE,      new String[] {"ESC-P"});
      res.put(COPY,         new String[] {"F11", "ESC-C"});
      res.put(CURSOR_DOWN,  new String[] {"CURSOR-DOWN", "CTRL-J"});
      res.put(CURSOR_LEFT,  new String[] {"CURSOR-LEFT", "CTRL-O"});
      res.put(CURSOR_RIGHT, new String[] {"CURSOR-RIGHT", "CTRL-L"});
      res.put(CURSOR_UP,    new String[] {"CURSOR-UP", "CTRL-K"});
      res.put(CUT,          new String[] {"F10", "ESC-X"});

      res.put(DEFAULT_POP_UP,   new String[] {"ESC-U"});
      res.put(DELETE_CHARACTER, new String[] {"DEL", "DELETE"});
      res.put(DELETE_COLUMN,    new String[] {"ESC-CTRL-Z"});
      res.put(DELETE_END_LINE,  new String[] {"ESC-K"});
      res.put(DELETE_FIELD,     new String[] {"ESC-CTRL-D"});
      res.put(DELETE_LINE,      new String[] {"CTRL-D"});
      res.put(DELETE_WORD,      new String[] {"ESC-D"});

      res.put(EDITOR_BACKTAB, new String[] {"CTRL-B"});
      res.put(EDITOR_TAB,     new String[] {"CTRL-G", "TAB"});
      res.put(END,            new String[] {"END", "ESC->", "ESC-."});
      res.put(END_ERROR,      new String[] {"F4", "CTRL-E", "PF4"});
      res.put(ENTER_MENUBAR,  new String[] {"F3", "PF3", "ESC-M"});
      res.put(ESC_FUNC,       new String[] {"ESC"});
      res.put(EXIT,           new String[] {"ESC-Q", "EXIT"});

      res.put(FIND,          new String[] {"CTRL-F", "FIND"});
      res.put(FIND_NEXT,     new String[] {"ESC-F"});
      res.put(FIND_PREVIOUS, new String[] {"ESC-I"});

      res.put(GET,  new String[] {"F5", "ESC-O"});
      res.put(GO,   new String[] {"F1", "CTRL-X", "PF1"});
      res.put(GOTO, new String[] {"ESC-G"});

      res.put(HELP,  new String[] {"F2", "ESC-?", "PF2"});
      res.put(HOME,  new String[] {"ESC-,", "ESC-<", "HOME"});

      res.put(INSERT_COLUMN,      new String[] {"ESC-CTRL-N"});
      res.put(INSERT_FIELD,       new String[] {"ESC-CTRL-G"});
      res.put(INSERT_FIELD_DATA,  new String[] {"ESC-CTRL-F"});
      res.put(INSERT_FIELD_LABEL, new String[] {"ESC-CTRL-E"});
      res.put(INSERT_MODE,        new String[] {"F9", "CTRL-T", "INS"});

      res.put(LEFT_END, new String[] {"ESC-CURSOR-LEFT"});

      res.put(MAIN_MENU, new String[] {"ESC-RETURN", "ESC-CTRL-M"});
      res.put(MOVE,      new String[] {"ESC-CTRL-V"});

      res.put(NEW,        new String[] {"ESC-N"});
      res.put(NEW_LINE,   new String[] {"CTRL-N"});
      res.put(NEXT_ERROR, new String[] {"ESC-E"});
      res.put(NEXT_FRAME, new String[] {"ESC-TAB", "ESC-CTRL-I"});
      res.put(NEXT_WORD,  new String[] {"CTRL-W"});

      res.put(OPEN_LINE_ABOVE, new String[] {"ESC-L"});
      res.put(OPTIONS,         new String[] {"ESC-CTRL-O"});

      res.put(PAGE_DOWN,  new String[] {"ESC-CURSOR-DOWN", "PAGE-DOWN"});
      res.put(PAGE_LEFT,  new String[] {"ESC-W"});
      res.put(PAGE_RIGHT, new String[] {"ESC-Y"});
      res.put(PAGE_UP,    new String[] {"ESC-CURSOR-UP", "PAGE-UP"});
      res.put(PASTE,      new String[] {"F12", "ESC-V"});
      res.put(PICK,       new String[] {"ESC-CTRL-P"});
      res.put(PICK_AREA,  new String[] {"ESC-CTRL-W"});
      res.put(PICK_BOTH,  new String[] {"ESC-CTRL-Q"});
      res.put(PREV_FRAME, new String[] {"ESC-CTRL-U"});
      res.put(PREV_WORD,  new String[] {"CTRL-P"});
      res.put(PUT,        new String[] {"F6", "ESC-S"});

      res.put(RECALL,         new String[] {"F7", "CTRL-R"});
      res.put(REPLACE,        new String[] {"ESC-R"});
      res.put(REPORTS,        new String[] {"ESC-CTRL-A"});
      res.put(RESUME_DISPLAY, new String[] {"CTRL-Q"});
      res.put(RETURN,         new String[] {"RETURN", "CTRL-M"});
      res.put(RIGHT_END,      new String[] {"ESC-CURSOR-RIGHT"});

      res.put(SAVE_AS,      new String[] {"ESC-A"});
      res.put(SCROLL_LEFT,  new String[] {"ESC-CTRL-L"});
      res.put(SCROLL_MODE,  new String[] {"ESC-T"});
      res.put(SCROLL_RIGHT, new String[] {"ESC-CTRL-R"});
      res.put(SETTINGS,     new String[] {"ESC-CTRL-@"});
      res.put(START_RESIZE, new String[] {"ESC-1"});
      res.put(STOP,         new String[] {"CTRL-C"});
      res.put(STOP_DISPLAY, new String[] {"CTRL-S"});

      res.put(TAB,        new String[] {"TAB", "CTRL-I"});
      res.put(TOP_COLUMN, new String[] {"ESC-CTRL-T"});

      res.put(UNIX_END,   new String[] {"CTRL-\\"});

      // special entries for key actions
      res.put(ENDKEY, new String[] {});
      res.put(ERROR,  new String[] {});
      
      return res;
   }
   
   /**
    * Check if the given key code is treated by rule 1.
    * 
    * @param    code
    *           The key code to check.
    *           
    * @return   <code>true</code> if rule 1 must be applied to the key code.
    */
   @Override
   protected boolean useRule1(int code)
   {
      return (code >= 1013 && code <= 1279) || super.useRule1(code);
   }
}
