/*
** Module   : TerminalOptions.java
** Abstract : configuration container
**
** Copyright (c) 2011-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 GES 20110921 Created initial version.
** 002 CA  20141029 Added flag to identify if the client needs to be ran in windows compatibility 
**                  mode.
*/

package com.goldencode.p2j.ui.client.chui.driver.swing;

import java.awt.*;

/**
 * Simple configuration container.
 */
public class TerminalOptions
{
   /** The default number of rows of text on the terminal screen. */
   public static int DEF_ROWS = 24;
   
   /** The default number of columns of text on the terminal screen. */
   public static int DEF_COLUMNS = 80;
   
   /** The default background color for each character. */
   public static Color DEF_BACKGROUND = Color.BLACK;
   
   /** The default foreground color for each character. */
   public static Color DEF_FOREGROUND = Color.decode("0xFFA500");
   
   /** The default color of the selection box. */
   public static Color DEF_SELECTION = Color.BLUE;
   
   /** The default font used for all text. */
   public static String DEF_FONTNAME = Font.MONOSPACED;
   
   /** The default point size used for all text. */
   public static int DEF_FONTSIZE = 12;
   
   /** The number of rows of text on the terminal screen. */
   public int rows = DEF_ROWS;
   
   /** The number of columns of text on the terminal screen. */
   public int columns = DEF_COLUMNS;
   
   /** The background color for each character. */
   public Color background = DEF_BACKGROUND;
   
   /** The foreground color for each character. */
   public Color foreground = DEF_FOREGROUND;
   
   /** The color of the box when the user selects a rectangle of text. */
   public Color selection = DEF_SELECTION;
   
   /** The font used for all text. */
   public String fontname = DEF_FONTNAME;
   
   /** The font's point size used for all text. */
   public int fontsize = DEF_FONTSIZE;
   
   /** Flag indicating if the client is running in windows compatibility mode. */
   public boolean underWindows = false;
   
   /**
    * Compare the given instance to the current instance and report if the
    * two are equivalent. This implementation compares the data stored in
    * each instance member-wise.
    *
    * @param    options
    *           The instance with which the current data is compared.
    *
    * @return   <code>true</code> if both instances contain equivalent data.
    */
   public boolean equals(TerminalOptions options)
   {
      return (rows                == options.rows                 &&
              columns             == options.columns              &&
              fontsize            == options.fontsize             &&
              background.getRGB() == options.background.getRGB()  &&
              foreground.getRGB() == options.foreground.getRGB()  &&
              selection.getRGB()  == options.selection.getRGB()   &&
              underWindows        == options.underWindows         &&
              fontname.equalsIgnoreCase(options.fontname));
   }
}
