/*
** Module   : ServerPropertiesInspector.java
** Abstract : Progress 4GL compatible System properties checking methods interface.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20140327 Created initial version.
** 002 CA  20141029 Added API to interrogate the server-side about the client's OS compatibility 
*                   mode.
*/

package com.goldencode.p2j.util;

/**
 * Interface describing the methods that gets different system variables and characteristics.
 * <p>
 * The accessor classes implementing this interface provide the way to access environment worker
 * classes on the server side.
 *
 * @author    EVL
 */
public interface ServerPropertiesInspector
{
   /**
    * Gets the current version string of the Progress compatible environment.
    * <p>
    * If no value is found via this lookup, then the default value of
    * "10.2B" will be returned.
    *
    * @return   The current version string.
    */
   public String getVersion();

   /**
    * Reports if the current server context is running in batch mode.
    * <p>
    * If no value is found via this lookup, then the default value of
    * <code>false</code> will be returned.
    *
    * @return   <code>true</code> if the current context is in batch mode.
    */
   public boolean isBatchMode();
   
   /**
    * Check the server-side configuration of this client - if it is running in windows 
    * compatibility mode or not.
    * 
    * @return   <code>true</code> if the client is running in windows compatibility mode.
    */
   public boolean isUnderWindowsFamily();
}
